@@ -50,6 +50,7 @@
 #'   be set in the global option \code{tinytex.engine_args}, e.g.,
 #'   \code{options(tinytex.engine_args = '-shell-escape'}).
 #' @param emulation Whether to emulate the executable \command{latexmk} using R.
+#'   Note that this is unused when \code{engine == 'tectonic'}.
 #' @param min_times,max_times The minimum and maximum number of times to rerun
 #'   the LaTeX engine when using emulation. You can set the global options
 #'   \code{tinytex.compile.min_times} or \code{tinytex.compile.max_times}, e.g.,
@@ -69,7 +70,7 @@
 #' @return A character string of the path of the output file (i.e., the value of
 #'   the \code{pdf_file} argument).
 latexmk = function(
-  file, engine = c('pdflatex', 'xelatex', 'lualatex', 'latex'),
+  file, engine = c('pdflatex', 'xelatex', 'lualatex', 'latex', 'tectonic'),
   bib_engine = c('bibtex', 'biber'), engine_args = NULL, emulation = TRUE,
   min_times = 1, max_times = 10, install_packages = emulation && tlmgr_writable(),
   pdf_file = gsub('tex$', 'pdf', file), clean = TRUE
@@ -115,6 +116,10 @@ latexmk = function(
     file_rename(pdf, pdf_file)
     pdf_file
   }
+  if (engine == 'tectonic') {
+    system2_quiet('tectonic', c(engine_args, shQuote(file)))
+    return(check_pdf())
+  }
   if (emulation) {
     latexmk_emu(
       file, engine, bib_engine, engine_args, min_times, max_times,
@@ -161,10 +166,11 @@ latexmk_emu = function(
     'nav', 'snm', 'vrb', 'ilg', 'ind', 'xwm', 'brf', 'run.xml'
   )
   base = gsub('[.]tex$', '', basename(file))
-  aux_files = setNames(paste(base, aux, sep = '.'), aux)
+  aux_files = paste(base, aux, sep = '.')
   aux_files = c(aux_files, 'preview.aux')  # generated by the preview package
   if (!is.null(output_dir <- getOption('tinytex.output_dir')))
     aux_files = file.path(output_dir, aux_files)
+  names(aux_files)[seq_along(aux)] = aux
   logfile = aux_files['log']; unlink(logfile)  # clean up the log before compilation
 
   # clean up aux files from LaTeX compilation
@@ -213,7 +219,7 @@ latexmk_emu = function(
         on_error()
       }, logfile = logfile, fail_rerun = verbose
     )
-    # PNAS you are the worst! Why don't you singal an error in case of missing packages?
+    # PNAS you are the worst! Why don't you signal an error in case of missing packages?
     if (res == 0 && !file.exists(filep)) on_error()
     invisible(res)
   }
@@ -290,9 +296,9 @@ tweak_aux = function(aux, x = readLines(aux)) {
   writeLines(x, aux)
 }
 
-needs_rerun = function(log) {
+needs_rerun = function(log, text = xfun::read_utf8(log)) {
   any(grepl(
-    '(Rerun to get |Please \\(re\\)run | Rerun LaTeX\\.)', readLines(log),
+    '(Rerun to get |Please \\(?re\\)?run | Rerun LaTeX\\.)', text,
     useBytes = TRUE
   ))
 }
@@ -525,6 +531,7 @@ detect_files = function(text) {
 
     '.* (tikzlibrary[^ ]+?[.]code[.]tex).*',
 
+    ".* Loading '([^']+)' aborted!",
     ".*! LaTeX Error: File `([^']+)' not found.*",
     ".* file ['`]?([^' ]+)'? not found.*",
     '.*the language definition file ([^ ]+) .*',
